@@ -114,6 +114,9 @@ class VCSFileStartHook(hook.Hook):
 
     def __call__(self):
         repo = self.repo
+        hgrcpath = repo.config['hgrc-path']
+        if hgrcpath is not None:
+            os.environ['HGRCPATH'] = hgrcpath
         rql = ('Any R, RT, RE, RLC, RSU, RP, RIRC WHERE R is Repository, '
                'NOT (R local_cache NULL AND R path NULL),'
                'R type RT, R encoding RE, R local_cache RLC, R source_url RSU, R path RP,'
@@ -203,6 +206,7 @@ class UpdateVFModificationDateHook(hook.Hook):
     __select__ = hook.Hook.__select__ & is_instance('DeletedVersionContent',
                                                     'VersionContent')
     events = ('after_add_entity',)
+    category = 'metadata'
 
     def __call__(self):
         VFModificationDateOp.get_instance(self._cw).add_data(self.entity)
@@ -212,6 +216,7 @@ class AddRevisionHook(hook.Hook):
     __regid__ = 'vcsfile.add_revision_hook'
     __select__ = hook.Hook.__select__ & is_instance('Revision')
     events = ('before_add_entity',)
+    # no category, mandatory hook
 
     def __call__(self):
         entity = self.entity
@@ -250,6 +255,7 @@ class AddVersionContentHook(hook.Hook):
     __regid__ = 'vcsfile.add_version_content_hook'
     __select__ = hook.Hook.__select__ & is_instance('VersionContent')
     events = ('before_add_entity',)
+    category = 'metadata'
 
     def __call__(self):
         edited = self.entity.cw_edited
@@ -270,6 +276,7 @@ class AddDeletedVersionContentHook(hook.Hook):
     __select__ = (hook.Hook.__select__ & is_instance('DeletedVersionContent')
                   & session.is_user_session())
     events = ('before_add_entity',)
+    # no category, mandatory hook
 
     def __call__(self):
         vcsrepohdlr, transaction = self.entity._vc_prepare()
@@ -283,6 +290,7 @@ class AddVersionedFileHook(hook.Hook):
     __select__ = (hook.Hook.__select__ & is_instance('VersionedFile')
                   & session.is_user_session())
     events = ('before_add_entity',)
+    category = 'integrity'
 
     def __call__(self):
         CheckVersionedFileOp(self._cw, entity=self.entity)
@@ -295,6 +303,7 @@ class SetRepoCacheBeforeAddHook(hook.Hook):
     __regid__ = 'clone_repo_after_add'
     __select__ = (hook.Hook.__select__ & is_instance('Repository'))
     events = ('before_add_entity',)
+    category = 'vcsfile.cache'
     order = 2
 
     def __call__(self):
@@ -310,6 +319,7 @@ class CloneRepoAfterAddHook(hook.Hook):
     __regid__ = 'clone_repo_after_add'
     __select__ = (hook.Hook.__select__ & is_instance('Repository'))
     events = ('after_add_entity',)
+    category = 'vcsfile.cache'
     order = 2
 
     def __call__(self):
@@ -327,6 +337,7 @@ class UpdateRepositoryHook(hook.Hook):
     __regid__ = 'vcsfile.update_repository_hook'
     __select__ = hook.Hook.__select__ & is_instance('Repository')
     events = ('before_update_entity', )
+    # XXX no category, contains integrity, mandatory and vcsfile.cache behaviour
 
     def __call__(self):
         vcsrepo = self.entity
@@ -361,6 +372,7 @@ class DeleteRepositoryHook(hook.Hook):
                   is_instance('Repository') &
                   score_entity(lambda x:x.local_cache))
     events = ('before_delete_entity',)
+    # XXX mandatory hook?
 
     def __call__(self):
         if self.entity.local_cache:
@@ -415,6 +427,7 @@ class CheckImmutableAttributeHook(hook.Hook):
                   & is_instance('Revision', 'DeletedVersionContent', 'VersionContent')
                   & session.is_user_session())
     events = ('before_update_entity',)
+    category = 'integrity'
 
     def __call__(self):
         for attr in self.entity.cw_edited:
@@ -428,6 +441,7 @@ class AddUpdateRepositoryHook(hook.Hook):
     __regid__ = 'vcsfile.add_update_repository_hook'
     __select__ = hook.Hook.__select__ & is_instance('Repository')
     events = ('after_add_entity', 'after_update_entity')
+    category = 'integrity'
     required_attrs = ('path', 'source_url')
     order = 1
 
@@ -455,8 +469,9 @@ class ClassifyVersionedFileHook(hook.Hook):
     repository (require cubicweb-tag and/or cubicweb-folder installed)
     """
     __regid__ = 'vcsfile.classify_versioned_file_hook'
-    events = ('after_add_entity', )
     __select__ = hook.Hook.__select__ & is_instance('VersionedFile')
+    events = ('after_add_entity', )
+    category = 'autoset'
 
     def __call__(self):
         try:
