@@ -89,7 +89,7 @@ class HGRepository(repo.VCSRepository):
             except (util.Abort, urllib2.URLError), ex:
                 raise bridge.VCSException(self.eid, 'url', str(ex))
         else:
-            self.info('pulling from %s into %s', remove_authinfo(url), self.path)
+            self.debug('pulling from %s into %s', remove_authinfo(url), self.path)
             vui = vcsfile_ui(self)
             try:
                 hgcmd.pull(vui, hg.repository(vui, self.path), source=str(url))
@@ -124,8 +124,9 @@ class HGRepository(repo.VCSRepository):
                             'X from_repository R, R eid %(r)s',
                             {'rev': actualrev, 'r': self.eid})
             return
-        self.info('hg repo %s: known revisions up to %s, repo revision %s',
-                  self.path, latestrev, actualrev)
+        if latestrev != actualrev:
+            self.info('hg repo %s: known revisions up to %s, repo revision %s',
+                      self.path, latestrev, actualrev)
         for i in xrange(latestrev + 1, actualrev + 1):
             try:
                 self.import_revision(repoentity, repo, i)
@@ -185,7 +186,7 @@ class HGRepository(repo.VCSRepository):
             upath = unicode(path, self.encoding, 'replace')
             if not (path_filter is None or upath.startswith(path_filter)):
                 continue
-            self._import_version_content(session, i, reveid, removed,
+            self._import_version_content(session, changeset, reveid, removed,
                                          path, upath, date, repo, ctx)
         for path in removed:
             upath = unicode(path, self.encoding, 'replace')
@@ -197,10 +198,10 @@ class HGRepository(repo.VCSRepository):
         parent_lrevs = [parent_idx[cs] for cs in parent_changesets]
         bridge.set_at_revision(session, reveid, parent_lrevs)
 
-    def _import_version_content(self, session, i, reveid, removed, path, upath,
+    def _import_version_content(self, session, changeset, reveid, removed, path, upath,
                                 date, repo, ctx):
         directory, fname = split(path)
-        session.transaction_data['vcs_importing'] = self.eid, directory, fname, i
+        session.transaction_data['vcs_importing'] = self.eid, directory, fname, changeset
         filectx = ctx[path]
         vcdata = {'data': Binary(filectx.data())}
         renameinfo = filectx.renamed()
@@ -280,13 +281,19 @@ class HGRepository(repo.VCSRepository):
         if strip and start_revision != 0:
             raise Exception('must start from revision 0 to strip')
         if strip and not repoentity.import_revision_content:
-            for etype in ('DeletedVersionContent', 'VersionContent', 'VersionedFile'):
+            for etype in ('DeletedVersionContent', 'VersionContent'):
                 rset = session.execute(
-                    'DELETE %s X WHERE X from_repository R, R eid %%(r)s' % etype,
+                    'DELETE %s X WHERE X from_revision REV, REV from_repository R, R eid %%(r)s' % etype,
                     {'r': self.eid})
                 if rset:
                     self.warning("deleted %s %s (content shouldn't be imported)",
                                  len(rset), session._(etype))
+            rset = session.execute(
+                'DELETE %s X WHERE X is VersionedFile, X from_repository R, R eid %(r)s',
+                {'r': self.eid})
+            if rset:
+                self.warning("deleted %s %s (content shouldn't be imported)",
+                             len(rset), session._(etype))
         else:
             rset = session.execute(
                 'DELETE VersionedFile X WHERE X from_repository R, R eid %(r)s, '
@@ -430,7 +437,7 @@ class HGRepository(repo.VCSRepository):
             if not vc:
                 self.warning('add missing file %s modified/added by revision', upath)
                 vceid, vfeid = self._import_version_content(
-                    session, i, rev.eid, removed, path, upath, date, repo, ctx)
+                    session, changeset, rev.eid, removed, path, upath, date, repo, ctx)
                 if stripidx is not None:
                     spop(stripidx['VersionedFile'], vfeid)
             else:
