@@ -174,6 +174,17 @@ class VCPrimaryView(idownloadable.IDownloadablePrimaryView):
         self.w('<h1>%s</h1>' % title)
         render_entity_summary(self, entity)
 
+    def render_data(self, entity, sourcemt, targetmt):
+        if entity.data:
+            return super(VCPrimaryView, self).render_data(entity, sourcemt, targetmt)
+        elif targetmt == 'text/html':
+            msg = self._cw._('File content is not accessible.  '
+                    'This may mean that the VCS repository is not accessible from the '
+                    'web frontend, or that it is no yet updated.')
+            self.w(u'<div class="error">%s</div>' % msg)
+            return True
+        return False
+
 
 class VCMetaDataView(baseviews.MetaDataView):
     """paragraph view of some metadata"""
